package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.StatisticalReportImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/12/14 18:05
 */

@RestController
@RequestMapping("/${api.version}/statisticalReport")
public class StatisticalReportController extends BaseRESTfulController {

    @Autowired
    StatisticalReportImpl statisticalReportService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    private final SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

    @ApiOperation(value="查询辅料燃料统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(220)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getRLFLReport")
    public RESTfulResult getRLFLReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String startTime,
                                               String endTime,
                                               Integer orderType
    ){
        mapValue.put("orderTypee", orderType);
        DataChange.queryDataByDate(startTime, endTime, mapValue, sdf);//根据时间段查询数据
        List<Map<String, Object>> allReport =  statisticalReportService.getAllPurchaseFLRLReport(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getRLFLReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, allReport,report);
        return success(pageList);
    }

    @ApiOperation(value="查询销售统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(423)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllSaleReport")
    public RESTfulResult getAllSaleReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       String startTime,
                                       String endTime,
                                       String carrierSsoId
    ){
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDate(startTime, endTime, mapValue, sdf);//根据时间段查询数据
        List<Map<String, Object>> allReport =  statisticalReportService.getAllSaleReportNum(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getAllSaleReport(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, allReport, report);
        return success(pageList);
    }

    @ApiOperation(value="查询零星物资进厂统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(424)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSporadicSuppliesReport1")
    public RESTfulResult getSporadicSuppliesReport1(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String startTime,
                                          String endTime,
                                          String carrierSsoId,
                                          String userId,
                                           String userIds,
                                           String con,
                                           Integer orderType
    ){
        if(carrierSsoId != null) {
            if (!"null".equals(carrierSsoId)) {
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDate(startTime, endTime, mapValue, sdf);//根据时间段查询数据
            if (userId!=null){
                mapValue.put("userId",userId);
            }
            if (orderType!=null){
                mapValue.put("orderType",orderType);
            }
            if (userIds!=null){
                mapValue.put("userIds",userIds);
            }
            if (con!=null&&!con.equals("undefined")){
                mapValue.put("con","%"+con+"%");
            }
        List<Map<String, Object>> allReport =  statisticalReportService.getSporadicSuppliesReportNum1(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSporadicSuppliesReport1(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, allReport, report);
        return success(pageList);
    }

    @ApiOperation(value="查询零星物资出厂统计报表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(425)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getSporadicSuppliesReport2")
    public RESTfulResult getSporadicSuppliesReport2(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   Integer apiId,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   String startTime,
                                                   String endTime,
                                                   String carrierSsoId,
                                                    String userId,
                                                    String userIds,
                                                    String con,
                                                    Integer orderType
    ){
        if(carrierSsoId != null){
            if(!"null".equals(carrierSsoId)){
                mapValue.put("carrierSsoId", carrierSsoId);
            }
        }
        DataChange.queryDataByDate(startTime, endTime, mapValue, sdf);//根据时间段查询数据
        if (con!=null&&!con.equals("undefined")){
            mapValue.put("con","%"+con+"%");
        }
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (orderType!=null){
            mapValue.put("orderType",orderType);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        List<Map<String, Object>> allReport =  statisticalReportService.getSporadicSuppliesReportNum2(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页数据
        List<Map<String, Object>> report = statisticalReportService.getSporadicSuppliesReport2(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, allReport, report);
        return success(pageList);
    }
}
